@@ -26,8 +26,8 @@
 #'   \code{"MH"}, \code{"Peto"}, \code{"GLMM"}, or \code{"SSW"}, can
 #'   be abbreviated.
 #' @param sm A character string indicating which summary measure
-#'   (\code{"RR"}, \code{"OR"}, \code{"RD"}, or \code{"ASD"}) is to be
-#'   used for pooling of studies, see Details.
+#'   (\code{"RR"}, \code{"OR"}, \code{"RD"}, \code{"ASD"}, or
+#'   \code{"DOR"}) is to be used for pooling of studies, see Details.
 #' @param incr Could be either a numerical value which is added to
 #'   each cell frequency for studies with a zero cell count or the
 #'   character string \code{"TACC"} which stands for treatment arm
@@ -40,8 +40,8 @@
 #'   cell frequency of all studies irrespective of zero cell counts.
 #' @param allstudies A logical indicating if studies with zero or all
 #'   events in both groups are to be included in the meta-analysis
-#'   (applies only if \code{sm} is equal to \code{"RR"} or
-#'   \code{"OR"}).
+#'   (applies only if \code{sm} is equal to \code{"RR"}, \code{"OR"},
+#'   or \code{"DOR"}).
 #' @param MH.exact A logical indicating if \code{incr} is not to be
 #'   added to all cell frequencies for studies with a zero cell count
 #'   to calculate the pooled estimate based on the Mantel-Haenszel
@@ -105,10 +105,11 @@
 #'   \code{"peters"}, can be abbreviated. See function
 #'   \code{\link{metabias}.}
 #' @param backtransf A logical indicating whether results for odds
-#'   ratio (\code{sm="OR"}) and risk ratio (\code{sm="RR"}) should be
-#'   back transformed in printouts and plots. If TRUE (default),
-#'   results will be presented as odds ratios and risk ratios;
-#'   otherwise log odds ratios and log risk ratios will be shown.
+#'   ratio (\code{sm="OR"}), risk ratio (\code{sm="RR"}), or
+#'   diagnostic odds ratio (\code{sm="DOR"}) should be back
+#'   transformed in printouts and plots. If TRUE (default), results
+#'   will be presented as odds ratios and risk ratios; otherwise log
+#'   odds ratios and log risk ratios will be shown.
 #' @param pscale A numeric defining a scaling factor for printing of
 #'   risk differences.
 #' @param title Title of meta-analysis / systematic review.
@@ -151,7 +152,11 @@
 #' \item Odds ratio (\code{sm = "OR"})
 #' \item Risk difference (\code{sm = "RD"})
 #' \item Arcsine difference (\code{sm = "ASD"})
+#' \item Diagnostic Odds ratio (\code{sm = "DOR"})
 #' }
+#'
+#' Note, mathematically, odds ratios and diagnostic odds ratios are
+#' identical, however, the labels in printouts and figures differ.
 #' 
 #' By default, both fixed effect and random effects models are
 #' considered (see arguments \code{comb.fixed} and
@@ -650,24 +655,24 @@
 #' # Use subset of Olkin (1995) to conduct meta-analysis based on
 #' # inverse variance method (with risk ratio as summary measure)
 #' #
-#' data(Olkin95)
-#' m1 <- metabin(event.e, n.e, event.c, n.c,
-#'               data = Olkin95, subset = c(41, 47, 51, 59),
+#' data(Olkin1995)
+#' m1 <- metabin(ev.exp, n.exp, ev.cont, n.cont,
+#'               data = Olkin1995, subset = c(41, 47, 51, 59),
 #'               method = "Inverse")
 #' summary(m1)
 #' 
 #' # Use different subset of Olkin (1995)
 #' #
-#' m2 <- metabin(event.e, n.e, event.c, n.c,
-#'               data = Olkin95, subset = year < 1970,
+#' m2 <- metabin(ev.exp, n.exp, ev.cont, n.cont,
+#'               data = Olkin1995, subset = year < 1970,
 #'               method = "Inverse", studlab = author)
 #' summary(m2)
 #' forest(m2)
 #' 
 #' # Meta-analysis with odds ratio as summary measure
 #' #
-#' m3 <- metabin(event.e, n.e, event.c, n.c,
-#'               data = Olkin95, subset = year < 1970,
+#' m3 <- metabin(ev.exp, n.exp, ev.cont, n.cont,
+#'               data = Olkin1995, subset = year < 1970,
 #'               sm = "OR", method = "Inverse", studlab = author)
 #' # Same meta-analysis result using 'update.meta' function
 #' m3 <- update(m2, sm = "OR")
@@ -695,8 +700,8 @@
 #' # Logistic regression model with (k = 4) fixed study effects
 #' # (default: model.glmm = "UM.FS")
 #' #
-#' m6 <- metabin(event.e, n.e, event.c, n.c,
-#'               data = Olkin95, subset = year < 1970,
+#' m6 <- metabin(ev.exp, n.exp, ev.cont, n.cont,
+#'               data = Olkin1995, subset = year < 1970,
 #'               method = "GLMM")
 #' # Same results:
 #' m6 <- update(m2, method = "GLMM")
@@ -729,8 +734,8 @@
 #' # Logistic regression model with (k = 70) fixed study effects
 #' # (about 18 seconds with Intel Core i7-3667U, 2.0GHz)
 #' #
-#' m10 <- metabin(event.e, n.e, event.c, n.c,
-#'                data = Olkin95, method = "GLMM")
+#' m10 <- metabin(ev.exp, n.exp, ev.cont, n.cont,
+#'                data = Olkin1995, method = "GLMM")
 #' summary(m10)
 #' 
 #' # Mixed-effects logistic regression model with random study effects
@@ -773,7 +778,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
                                               nomatch = NA)),
                              "OR", gs("smbin")),
                     incr = gs("incr"), allincr = gs("allincr"),
-                    addincr = gs("addincr"), allstudies = gs("allstudies"),
+                    addincr = gs("addincr"),
+                    allstudies = gs("allstudies"),
                     MH.exact = gs("MH.exact"), RR.Cochrane = gs("RR.Cochrane"),
                     Q.Cochrane =
                       gs("Q.Cochrane") & method == "MH" & method.tau == "DL",
@@ -797,7 +803,9 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
                     prediction = gs("prediction"),
                     level.predict = gs("level.predict"),
                     ##
-                    method.bias = ifelse(sm == "OR", "score", gs("method.bias")),
+                    method.bias = ifelse(sm == "OR", "score",
+                                  ifelse(sm == "DOR", "deeks",
+                                         gs("method.bias"))),
                     ##
                     backtransf = gs("backtransf"),
                     pscale = 1,
@@ -848,12 +856,11 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   chklogical(prediction)
   chklevel(level.predict)
   ##
-  method.bias <- setchar(method.bias,
-                         c("rank", "linreg", "mm", "count", "score", "peters"))
+  method.bias <- setchar(method.bias, .settings$meth4bias)
   ##
   chklogical(backtransf)
   ##
-  chknumeric(pscale, single = TRUE)
+  chknumeric(pscale, length = 1)
   ##
   chklogical(keepdata)
   ##
@@ -1188,7 +1195,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     if (allstudies)
       incl <- rep(1, k.all)
     else {
-      if (sm == "OR")
+      if (sm %in% c("OR", "DOR"))
         incl <- ifelse((event.c == 0   & event.e == 0) |
                        (event.c == n.c & event.e == n.e), NA, 1)
       if (sm == "RR")
@@ -1222,12 +1229,14 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   ##
   sel <- switch(sm,
                 OR = ((n.e - event.e) == 0 | event.e == 0 |
-                        (n.c - event.c) == 0 | event.c == 0),
+                      (n.c - event.c) == 0 | event.c == 0),
                 RD = ((n.e - event.e) == 0 | event.e == 0 |
-                        (n.c - event.c) == 0 | event.c == 0),
+                      (n.c - event.c) == 0 | event.c == 0),
                 RR = ((n.e - event.e) == 0 | event.e == 0 |
-                        (n.c - event.c) == 0 | event.c == 0),
-                ASD = rep(FALSE, length(event.e)))
+                      (n.c - event.c) == 0 | event.c == 0),
+                ASD = rep(FALSE, length(event.e)),
+                DOR = ((n.e - event.e) == 0 | event.e == 0 |
+                       (n.c - event.c) == 0 | event.c == 0))
   ##
   sel[is.na(incl)] <- FALSE
   ##
@@ -1362,7 +1371,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   ##
   ## Estimation of treatment effects in individual studies
   ##
-  if (sm == "OR") {
+  if (sm %in% c("OR", "DOR")) {
     if (method %in% c("MH", "Inverse", "GLMM", "SSW")) {
       ##
       ## Cooper & Hedges (1994), p. 251-2
@@ -1453,7 +1462,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     incr.e <- incr.e * (!MH.exact)
     incr.c <- incr.c * (!MH.exact)
     ##
-    if (sm == "OR") {
+    if (sm %in% c("OR", "DOR")) {
       ##
       ## Cooper & Hedges (1994), p. 253-5 (MH.exact == TRUE)
       ##
@@ -1647,7 +1656,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     res$w.fixed <- w.fixed
     res$lower.fixed <- ci.f$lower
     res$upper.fixed <- ci.f$upper
-    res$zval.fixed <- ci.f$z
+    res$statistic.fixed <- ci.f$statistic
     res$pval.fixed <- ci.f$p
   }
   ##
@@ -1680,7 +1689,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     res$seTE.random <- seTE.random
     res$lower.random <- ci.r$lower
     res$upper.random <- ci.r$upper
-    res$zval.random <- ci.r$z
+    res$statistic.random <- ci.r$statistic
     res$pval.random <- ci.r$p
     ##
     ## Prediction interval
@@ -1754,7 +1763,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     res$w.random <- w.random
     res$lower.random <- ci.r$lower
     res$upper.random <- ci.r$upper
-    res$zval.random <- ci.r$z
+    res$statistic.random <- ci.r$statistic
     res$pval.random <- ci.r$p      
   }
   ##
